.. _tutorials:

Tutorials
=========

We have a number of tutorial notebooks. If you like to run them interactively, you can launch them on Binder without
having to install anything.

We assume basic familiarity with `scikit-learn`_. If you haven’t worked with scikit-learn before, check out their
`getting-started guide`_.

The notebook files can be found `here <https://github.com/alan-turing-institute/sktime/blob/main/examples>`_.

.. _scikit-learn: https://scikit-learn.org/stable/
.. _getting-started guide: https://scikit-learn.org/stable/getting_started.html

.. nbgallery::
    :glob:

    examples/*
